@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 
-# Copyright 2012 Chris Taylor
+# Copyright 2013 Chris Taylor
 #
 # This file is part of caatinga.
 #
@@ -57,11 +57,11 @@ class CommandArgsTestCase(unittest.TestCase):
             a.deleteOldest,
             True)
 
-##    def test_CleanOptionGetsSet(self):
-##        a = CommandArgs(["--clean"])
-##        self.assertEqual(
-##            a.clean,
-##            True)
+    def test_CleanOptionGetsSet(self):
+        a = CommandArgs(["--clean"])
+        self.assertEqual(
+            a.clean,
+            True)
 
     def test_LongDeleteOldestGetsSet(self):
         a = CommandArgs(["--delete-oldest"])
